pub trait CpuCoreLocalState {
// Required methods
spec fn belongs_to_cpu(self, cpu: CpuId) -> bool;
spec fn local_key(self) -> Seq<Loc>;
}Expand description
A typed collection of resources that belongs permanently to one CPU.
Implementations may aggregate any number of differently typed CPU-local
points-to resources in a tracked struct. The predicate must state that all
resources in the aggregate belong to cpu. local_key must faithfully and
stably list their identities: changing, replacing, reordering, adding, or
removing a resource must change the key.